summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codegenobjectwithtextblocks.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/codegenobjectwithtextblocks.h')
-rw-r--r--umbrello/umbrello/codegenobjectwithtextblocks.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/umbrello/umbrello/codegenobjectwithtextblocks.h b/umbrello/umbrello/codegenobjectwithtextblocks.h
index c21aacf2..0e522e83 100644
--- a/umbrello/umbrello/codegenobjectwithtextblocks.h
+++ b/umbrello/umbrello/codegenobjectwithtextblocks.h
@@ -45,7 +45,7 @@ public:
/**
* Constructor
*/
- CodeGenObjectWithTextBlocks ( CodeDocument *parent );
+ CodeGenObjectWithTextBlocks ( CodeDocument *tqparent );
/**
* Empty Destructor
@@ -129,7 +129,7 @@ public:
virtual TextBlock * findTextBlockByTag ( const TQString &tag );
/**
- * @return QString
+ * @return TQString
* @param prefix
*/
virtual TQString getUniqueTag (const TQString& prefix = "" ) = 0;
@@ -140,9 +140,9 @@ public:
virtual CodeBlockWithComments * newCodeBlockWithComments() = 0;
virtual HierarchicalCodeBlock * newHierarchicalCodeBlock() = 0;
/** Find the direct parent for a given textblock. This
* may be any object which holds text blocks, e.g. a CodeGenObjectWithTextBlocks.
* @return parent object. Could return null if the textblock is missing from the
* branch of the document tree being examined.
*/
CodeGenObjectWithTextBlocks * findParentObjectForTaggedTextBlock (const TQString & tag);
@@ -165,7 +165,7 @@ protected:
* in this vanilla version, we only load comments and codeblocks
* as they are the only instanciatable (vanilla) things
* this method should be overridden if this class is inherited
- * by some other class that is concrete and takes children
+ * by some other class that is concrete and takes tqchildren
* derived from codeblock/codecomment/hierarchicalcb/ownedhiercodeblock
*/
virtual void loadChildTextBlocksFromNode ( TQDomElement & root);
@@ -140,9 +140,9 @@ public:
virtual CodeBlockWithComments * newCodeBlockWithComments() = 0;
virtual HierarchicalCodeBlock * newHierarchicalCodeBlock() = 0;
- /** Find the direct parent for a given textblock. This
+ /** Find the direct tqparent for a given textblock. This
* may be any object which holds text blocks, e.g. a CodeGenObjectWithTextBlocks.
@@ -140,9 +140,9 @@ public:
* may be any object which holds text blocks, e.g. a CodeGenObjectWithTextBlocks.
- * @return parent object. Could return null if the textblock is missing from the
+ * @return tqparent object. Could return null if the textblock is missing from the
* branch of the document tree being examined.
*/